@@ -23,7 +23,7 @@ sub _populate {
             [     4,  'C', 3        ],
             [     5,  'D', 4        ],
             [     6,  'E', 4        ],
-            [     7,  'F', 2        ],
+            [     7,  '♥', 2        ],
             [     8,  'G', 7        ],
             [     9,  'E', 7        ],
             [     10, 'I', 9        ],
